gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-donau] branch master updated: rename ctx


From: gnunet
Subject: [taler-donau] branch master updated: rename ctx
Date: Sat, 06 Jan 2024 14:28:36 +0100

This is an automated email from the git hooks/post-receive script.

johannes-casaburi pushed a commit to branch master
in repository donau.

The following commit(s) were added to refs/heads/master by this push:
     new 66e613f  rename ctx
66e613f is described below

commit 66e613f504317e14ca226739118bae9d08361c34
Author: Casaburi Johannes <johannes.casaburi@students.bfh.ch>
AuthorDate: Sat Jan 6 14:28:04 2024 +0100

    rename ctx
---
 src/donau/donau-httpd_post-charity.c | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/src/donau/donau-httpd_post-charity.c 
b/src/donau/donau-httpd_post-charity.c
index d5e9742..c97f81e 100644
--- a/src/donau/donau-httpd_post-charity.c
+++ b/src/donau/donau-httpd_post-charity.c
@@ -33,7 +33,7 @@
 /**
  * Closure for #insert_charity()
  */
-struct DecisionContext
+struct InsertCharityContext
 {
   /**
    * Charity name
@@ -57,7 +57,7 @@ struct DecisionContext
  * IF it returns the soft error code, the function MAY be called again to
  * retry and MUST not queue a MHD response.
  *
  * @param cls closure with a `struct DecisionContext`
  * @param connection MHD request which triggered the transaction
  * @param[out] mhd_ret set to MHD response status for @a connection,
  *             if transaction failed (!)
@@ -68,12 +68,12 @@ insert_charity (void *cls,
                 struct MHD_Connection *connection,
                 MHD_RESULT *mhd_ret)
 {
-  struct DecisionContext *dc = cls;
+  struct InsertCharityContext *icc = cls;
   enum GNUNET_DB_QueryStatus qs;
 
   qs = TEH_plugin->insert_charity (DH_plugin->cls,
-                                   dc->charity_name,
-                                   dc->charity_url);
+                                   icc->charity_name,
+                                   icc->charity_url);
   if (qs <= 0)
   {
     if (GNUNET_DB_STATUS_SOFT_ERROR != qs)
@@ -97,13 +97,13 @@ DH_handler_charity_post (
   struct MHD_Connection *connection,
   const json_t *root)
 {
-  struct DecisionContext dc;
+  struct InsertCharityContext icc;
 
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_array_const ("charity_url",
-                                  &dc.charity_url),
+                                  &icc.charity_url),
     GNUNET_JSON_spec_array_const ("charity_name",
-                                  &dc.charity_name),
+                                  &icc.charity_name),
     GNUNET_JSON_spec_end ()
   };
 
@@ -131,7 +131,7 @@ DH_handler_charity_post (
                                TEH_MT_REQUEST_OTHER,
                                &mhd_ret,
                                &insert_charity,
-                               &dc))
+                               &icc))
     {
       return mhd_ret;
     }
@@ -57,7 +57,7 @@ struct DecisionContext
  * retry and MUST not queue a MHD response.
  *
- * @param cls closure with a `struct DecisionContext`
+ * @param cls closure with a `struct InsertCharityContext`
  * @param connection MHD request which triggered the transaction
  * @param[out] mhd_ret set to MHD response status for @a connection,

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]